/**
 *  Copyright (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  Licensed under the GPL, Version 3.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.gnu.org/licenses/gpl.html
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * --------------------------------------------------------------------------
 *  版权 (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  本开源软件遵循 GPL 3.0 协议;
 *  如果您不遵循此协议，则不被允许使用此文件。
 *  你可以从下面的地址获取完整的协议文本
 *
 *       http://www.gnu.org/licenses/gpl.html
 */
package org.tinygroup.bumgt.cmd;

import java.util.List;

import org.apache.commons.vfs2.FileObject;
import org.apache.commons.vfs2.FileSystemException;
import org.apache.commons.vfs2.FileSystemManager;
import org.apache.commons.vfs2.VFS;
import org.tinygroup.bu.config.BusinessUnitInfo;
import org.tinygroup.bu.loader.BusinessUnitLoader;
import org.tinygroup.bu.loader.impl.BusinessUnitLoaderImpl;
import org.tinygroup.bu.util.BusinessUnitUtil;
import org.tinygroup.command.CommandGoalExecutor;
import org.tinygroup.command.CommandSystem;
import org.tinygroup.context.Context;
import org.tinygroup.logger.LogLevel;
import org.tinygroup.logger.Logger;
import org.tinygroup.logger.LoggerFactory;

/**
 * 列出插件的jar列表
 * @author luoguo
 *
 */

public class BuJarListCommand implements CommandGoalExecutor {

	private final int JAR_SPACE = 2;
	private final int JAR_DETAIL_SPACE = 4;
	private boolean showDetail;
	private static Logger logger = LoggerFactory
			.getLogger(BuJarListCommand.class);

	public boolean isShowDetail() {
		return showDetail;
	}

	public void setShowDetail(boolean showDetail) {
		this.showDetail = showDetail;
	}

	public void execute(CommandSystem commandHelper, Context context) {

		logger.logMessage(LogLevel.DEBUG, "开始执行指令：列出业务单元目录下所有Jar包");

		String path = context.get(BusinessUnitUtil.BU_BASE_DIR);
		if (path == null) {
			path = BusinessUnitUtil.getBuDir();
		}
		logger.logMessage(LogLevel.DEBUG, "扫描目录为{0}", path);

		try {
			FileSystemManager fsManager = VFS.getManager();
			FileObject dir = fsManager.resolveFile(path);

			if (dir.getChildren().length == 0) {
				commandHelper.indentPrint(
						"目录为空", 0);
				commandHelper.println();
				return;
			}
			commandHelper.indentPrint("目录包含：", 0);
			commandHelper.println();

			for (FileObject f : dir.getChildren()) {
				showFile(commandHelper, f);
			}

		} catch (FileSystemException e) {
			logger.logMessage(LogLevel.DEBUG, "遍历目录{0}时出错", path);
		}

		logger.logMessage(LogLevel.DEBUG, "指令执行完毕：列出业务单元目录下所有Jar包");
	}

	private void showFile(CommandSystem commandHelper, FileObject f) {
		String buPath = f.getName().toString();
		if (buPath.endsWith(".jar")) {
			commandHelper.indentPrint(f.getName().getBaseName().toString(),
					JAR_SPACE);
			commandHelper.println();
			if (showDetail) {
				showFileDetail(commandHelper, f);
			}
		}
	}

	private void showFileDetail(CommandSystem commandHelper, FileObject f) {
		String buPath = f.getName().toString();
		BusinessUnitLoader loader = new BusinessUnitLoaderImpl();
		List<BusinessUnitInfo> list = loader.listJar(buPath);
		if(list==null||list.size()==0){
			showNoInfo(commandHelper);;
		}else{
			for (BusinessUnitInfo info : list) {
				showBusInfo(commandHelper, info);
			}
		}
		
	}

	private void showBusInfo(CommandSystem commandHelper, BusinessUnitInfo info) {
			String infoStr = String.format("业务单元[package:%s,name:%s,version:%s]", info.getPackageName(),
					info.getName(),info.getVersion());
			commandHelper.indentPrint(infoStr, JAR_DETAIL_SPACE);
			commandHelper.println();
	}
	
	private void showNoInfo(CommandSystem commandHelper) {
		String info = String.format("无业务单元");
		commandHelper.indentPrint(info, JAR_DETAIL_SPACE);
		commandHelper.println();
	}

}
