/**
 *  Copyright (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  Licensed under the GPL, Version 3.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.gnu.org/licenses/gpl.html
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * --------------------------------------------------------------------------
 *  版权 (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  本开源软件遵循 GPL 3.0 协议;
 *  如果您不遵循此协议，则不被允许使用此文件。
 *  你可以从下面的地址获取完整的协议文本
 *
 *       http://www.gnu.org/licenses/gpl.html
 */
package org.tinygroup.bumgt.cmd;

import java.util.List;

import org.tinygroup.bu.BusinessUnitManager;
import org.tinygroup.bu.BusinessUnitManagerFactory;
import org.tinygroup.bu.config.BusinessUnitInfo;
import org.tinygroup.command.CommandGoalExecutor;
import org.tinygroup.command.CommandSystem;
import org.tinygroup.context.Context;
import org.tinygroup.logger.LogLevel;
import org.tinygroup.logger.Logger;
import org.tinygroup.logger.LoggerFactory;

/**
 * 查询业务单元状态
 * @author luoguo
 *
 */

public class BuQueryCommand  implements CommandGoalExecutor {
	private Logger logger = LoggerFactory.getLogger(BuQueryCommand.class);
	
	protected void actionAllPlugin(CommandSystem commandHelper, Context context) {
		logger.logMessage(LogLevel.DEBUG, "开始执行指令：查询所有业务单元信息");
		BusinessUnitManager buMananger = BusinessUnitManagerFactory.getManager();
		List<BusinessUnitInfo> list = buMananger.getBusinessUnitInfoList();
		for (BusinessUnitInfo plugin : list) {
			actionPlugin(commandHelper, context, plugin);
		}
		logger.logMessage(LogLevel.DEBUG, "指令执行完毕：查询所有业务单元信息");
	}

	
	protected void actionPlugin(CommandSystem commandHelper, Context context,
			BusinessUnitInfo buInfo) {
		logger.logMessage(LogLevel.DEBUG, "开始执行指令：查询业务单元[pakcage:{0},name:{1},version:{2}]信息",
				buInfo.getPackageName(),buInfo.getName(),buInfo.getVersion());
		
		commandHelper.indentPrint(String.format("业务单元状态:[pakcage:%s,name:%s,version:%s]",
				buInfo.getPackageName(),buInfo.getName(),buInfo.getVersion()),0);
		
		commandHelper.println();
		logger.logMessage(LogLevel.DEBUG, "指令执行完毕：查询业务单元[pakcage:{0},name:{1},version:{2}]信息",
				buInfo.getPackageName(),buInfo.getName(),buInfo.getVersion());
	}

	public void execute(CommandSystem commandHelper, Context context) {
		actionAllPlugin(commandHelper, context);
	}

	
}
